//***************************************************************************
//  The dd-GIF Library Version 1.0 Manifest Constants
//  Copyright (c) 1994, digital diversions, All Rights Reserved.
//
//  YOU MUST INCLUDE THIS FILE IN YOUR PROGRAMS FOR THE DD-GIF
//  LIBRARY TO WORK. IF YOU DON'T INCLUDE THIS FILE, YOUR PROGRAM
//  WILL NOT LINK.
//  Example of include statement:
//      #include "dd.ch"
//
//**************************************************************************

//***************************************************************************
// fast updates or BIOS updates
//***************************************************************************
#define DD_BIOS  0
#define DD_FAST  1

//***************************************************************************
// Use the image's default background, or the darkest background available
// in the image's palette.
//***************************************************************************
#define DD_DEFAULTBACKGROUND 0
#define DD_DARKESTBACKGROUND 1

//***************************************************************************
// Value to add to a the Color value in a Call to ddSay() to XOr the text
// onto the screen
//***************************************************************************
#define DD_XOR  256

//***************************************************************************
// Return values from ddShowGif()
//***************************************************************************
#define DDGIF_OK           0       //All OK
#define DDGIF_NOTFOUND    -1       //GIF File specified was not found
#define DDGIF_NOFILESPEC  -2       //No GIF file was specified
#define DDGIF_NOTGIFFILE  -3       //the file specified is not GIF file
#define DDGIF_INVALIDPARM -5       //Invalid or No Parms passed

// The following errors indicate a corrupt GIF image!
#define DDGIF_NOTERM      -100     //There is no GIF description terminator
#define DDGIF_EOF         -101     //Unexpected EOF in GIF File
#define DDGIF_BADMASK     -102     //Bad LZW Mask Code
#define DDGIF_BADCODE     -103     //Bad LZW Code
#define DDGIF_STACKOVRFLW -104     //GIF Stack overflow
#define DDGIF_HASHOVRFLW  -105     //Hash Table Overflow
#define DDGIF_INVALIDBITS -106     //Invalid bits per pixel - valid range is
                                   //2 (2 Color img) thru 8 (256 Color Img)


//***************************************************************************
// video mode definitions for ddSetMode()
//***************************************************************************
#define DD_TEXT     3
#define DD_VGA16    18
#define DD_VGA256   19

//***************************************************************************
// Return values from ddSetMode()
//***************************************************************************
#define DDSETMODE_OK          0         // All OK
#define DDSETMODE_INVALID     -1        // Invalid Video Mode Passed 
#define DDSETMODE_INVALIDPARM -2        // No Parms passed


//***************************************************************************
// Return values from ddSay()
//***************************************************************************
#define DDSAY_OK                  0  // All OK
#define DDSAY_INVALIDFONTBUFFER  -1  // Font buffer is not the right size
                                     // for an 8x16 or 8x8 font.
#define DDSAY_OFFSCREEN          -2  // The text to print went off the screen
#define DDSAY_INVALIDPARM        -3  // Invalid or No Parms passed


//***************************************************************************
// return values from ddLdFont()
// any other value is the size of the Font Map.
//***************************************************************************
#define DDLDFONT_NOTFOUND    -1      // The font file was not found.
#define DDLDFONT_BUFFERSIZE  -2      // The Font Buffer is not large enough
                                     // to handle the Font Map. 
#define DDLDFONT_FONTFILEERR -3      // The font file is not the right
                                     // size for an 8x16 or 8x8 font.
#define DDLDFONT_INVALIDPARM -99     // Invalid or No Parms passed


//***************************************************************************
//  ddGIFInfo()  information type definitions
//***************************************************************************
#define DDGIFINFO_HEIGHT      0      // Get GIF Image Height
#define DDGIFINFO_WIDTH       1      // Get GIF Image Width
#define DDGIFINFO_LEFT        2      // Get GIF Left Coordinate
#define DDGIFINFO_TOP         3      // Get GIF Top Coordinate
#define DDGIFINFO_INTERLACED  4      // Get GIF Interlace Flag
#define DDGIFINFO_COLORS      5      // Get GIF Image Number of Colors

//***************************************************************************
// Return values from ddGIFInfo()
// Any return value other than what is listed here is dependent on the 
// information type request.
//***************************************************************************
#define DDGIFINFO_NOTFOUND    -1     //GIF File specified was not found
#define DDGIFINFO_NOFILESPEC  -2     //No GIF file was specified
#define DDGIFINFO_NOTGIFFILE  -3     //the file specified is not GIF file
#define DDGIFINFO_NOTERM      -4     //There is no GIF file description 
                                     //terminator, probably corrupt
#define DDGIFINFO_INVALIDPARM -5     //Invalid or No Parms passed
#define DDGIFINFO_CORRUPT     -99    //The GIF Image file is corrupt
                                     //ddSHOWGIF() was unable to process it.


//***************************************************************************
// Return values from ddLine()
//***************************************************************************
#define DDLINE_OK              0     // All OK
#define DDLINE_INVALIDPARM     -99   // Invalid or No Parms passed

//***************************************************************************
// Return values from ddBox()
//***************************************************************************
#define DDBOX_OK              0     // All OK
#define DDBOX_INVALIDPARM     -99   // Invalid or No Parms passed

//***************************************************************************
// Return values from ddFill()
//***************************************************************************
#define DDFILL_OK              0     // All OK
#define DDFILL_INVALIDPARM     -99   // Invalid or No Parms passed

//***************************************************************************
// Return values for ddGIFVer()
//***************************************************************************
#define DDGIFVER_ERROR        NIL    // An error occurred

//***************************************************************************
// The color parameter for ddColor()
//***************************************************************************
#define DDCOLOR_BRIGHTEST       0    // find the brightest color
#define DDCOLOR_DARKEST         1    // find the darkest color

//***************************************************************************
// The return values for ddColor(), any other value is the palette color
// number of the color type requested.
//***************************************************************************
#define DDCOLOR_INVALIDPARM    -99   //Invalid or no parms passed

//***************************************************************************
// The first 16 colors of the Default VGA Pallete. 
//      NOTE: These colors can (and most likely do) change when an image is
//            displayed.
//***************************************************************************
#define DD_BLACK                0
#define DD_BLUE                 1
#define DD_GREEN                2
#define DD_CYAN                 3   //the crayola Blue - Green
#define DD_RED                  4
#define DD_MAGENTA              5
#define DD_BROWN                6   // or dark yellow
#define DD_LIGHTGREY            7   // or normal intensity white
#define DD_DARKGREY             8   // may appear black on some screens
#define DD_LIGHTBLUE            9  
#define DD_LIGHTGREEN          10   
#define DD_LIGHTCYAN           11
#define DD_LIGHTRED            12
#define DD_LIGHTMAGENTA        13
#define DD_YELLOW              14   // or light yellow
#define DD_WHITE               15   // or bright white


//***************************************************************************
// The translate pattern for the ddSetMode Function.
//***************************************************************************
#translate ddSetMode(<mode>)  =>;
        _ddmode(<mode>)            ;;
        m->ddsvcsr = setcursor(1)  ;;
        inkey()                    ;;
        setcursor(m->ddsvcsr)     

#translate ddSetMode() =>;
        _ddmode()


